@@ -31,6 +31,10 @@ export function FilesView({ repo }: FilesViewProps) {
       sortType: 'string',
       cell: ({ row: { original } }: FileCell<'path'>) => {
         const { path } = original;
+        const isDotKeepFile = getIsDotKeepFile(path);
+        if (isDotKeepFile) {
+          return path;
+        }
         return <a href={`${PROVISIONING_URL}/${name}/file/${path}`}>{path}</a>;
       },
     },
@@ -44,6 +48,10 @@ export function FilesView({ repo }: FilesViewProps) {
       header: '',
       cell: ({ row: { original } }: FileCell<'path'>) => {
         const { path } = original;
+        const isDotKeepFile = getIsDotKeepFile(path);
+        if (isDotKeepFile) {
+          return null;
+        }
         return (
           <Stack>
             {(path.endsWith('.json') || path.endsWith('.yaml') || path.endsWith('.yml')) && (
@@ -84,3 +92,8 @@ export function FilesView({ repo }: FilesViewProps) {
     </Stack>
   );
 }
+
+function getIsDotKeepFile(path: string): boolean {
+  // e.g. 'dashboards/.keep' → true, 'dashboards/example.keep.json' → false
+  return path.split('/').pop() === '.keep';
+}
